@@ -59,6 +59,7 @@
 #include "tecdiving_divecomputereu.h"
 #include "mclean_extreme.h"
 #include "liquivision_lynx.h"
+#include "sporasub_sp2.h"
 
 // Not merged upstream yet
 #include "garmin.h"
@@ -224,6 +225,9 @@ dc_device_open (dc_device_t **out, dc_context_t *context, dc_descriptor_t *descr
 	case DC_FAMILY_LIQUIVISION_LYNX:
 		rc = liquivision_lynx_device_open (&device, context, iostream);
 		break;
+	case DC_FAMILY_SPORASUB_SP2:
+		rc = sporasub_sp2_device_open (&device, context, iostream);
+		break;
 	default:
 		return DC_STATUS_INVALIDARGS;
 
