@@ -59,6 +59,7 @@
 #include "tecdiving_divecomputereu.h"
 #include "mclean_extreme.h"
 #include "liquivision_lynx.h"
+#include "sporasub_sp2.h"
 
 // Not merged upstream yet
 #include "garmin.h"
@@ -185,6 +186,9 @@ dc_parser_new_internal (dc_parser_t **out, dc_context_t *context, dc_family_t fa
 	case DC_FAMILY_LIQUIVISION_LYNX:
 		rc = liquivision_lynx_parser_create (&parser, context, model);
 		break;
+	case DC_FAMILY_SPORASUB_SP2:
+		rc = sporasub_sp2_parser_create (&parser, context);
+		break;
 	default:
 		return DC_STATUS_INVALIDARGS;
 
