@@ -78,7 +78,7 @@ typedef struct suunto_eonsteel_parser_t {
 	struct dc_field_cache cache;
 } suunto_eonsteel_parser_t;
 
-typedef int (*eon_data_cb_t)(unsigned short type, const struct type_desc *desc, const unsigned char *data, int len, void *user);
+typedef int (*eon_data_cb_t)(unsigned short type, const struct type_desc *desc, const unsigned char *data, unsigned int len, void *user);
 
 static const struct {
 	const char *name;
@@ -115,7 +115,6 @@ static const struct {
 
 static enum eon_sample lookup_descriptor_type(suunto_eonsteel_parser_t *eon, struct type_desc *desc)
 {
-	int i;
 	const char *name = desc->desc;
 
 	// Not a sample type? Skip it
@@ -138,7 +137,7 @@ static enum eon_sample lookup_descriptor_type(suunto_eonsteel_parser_t *eon, str
 	name += 8;
 
 	// .. and look it up in the table of sample type strings
-	for (i = 0; i < C_ARRAY_SIZE(type_translation); i++) {
+	for (size_t i = 0; i < C_ARRAY_SIZE(type_translation); i++) {
 		if (!strcmp(name, type_translation[i].name))
 			return type_translation[i].type;
 	}
@@ -147,8 +146,7 @@ static enum eon_sample lookup_descriptor_type(suunto_eonsteel_parser_t *eon, str
 
 static const char *desc_type_name(enum eon_sample type)
 {
-	int i;
-	for (i = 0; i < C_ARRAY_SIZE(type_translation); i++) {
+	for (size_t i = 0; i < C_ARRAY_SIZE(type_translation); i++) {
 		if (type == type_translation[i].type)
 			return type_translation[i].name;
 	}
@@ -334,10 +332,10 @@ static int record_type(suunto_eonsteel_parser_t *eon, unsigned short type, const
 	return 0;
 }
 
-static int traverse_entry(suunto_eonsteel_parser_t *eon, const unsigned char *p, int len, eon_data_cb_t callback, void *user)
+static int traverse_entry(suunto_eonsteel_parser_t *eon, const unsigned char *p, int size, eon_data_cb_t callback, void *user)
 {
-	const unsigned char *name, *data, *end, *last, *one_past_end = p + len;
-	int textlen, type;
+	const unsigned char *name, *data, *end, *last, *one_past_end = p + size;
+	int textlen, id;
 	int rc;
 
 	// First two bytes: zero and text length
@@ -356,7 +354,7 @@ static int traverse_entry(suunto_eonsteel_parser_t *eon, const unsigned char *p,
 
 	// Two bytes of 'type' followed by the name/descriptor, followed by the data
 	data = name + textlen;
-	type = array_uint16_le(name);
+	id = array_uint16_le(name);
 	name += 2;
 
 	if (*name != '<') {
@@ -364,7 +362,7 @@ static int traverse_entry(suunto_eonsteel_parser_t *eon, const unsigned char *p,
 		return -1;
 	}
 
-	record_type(eon, type, (const char *) name, textlen-3);
+	record_type(eon, id, (const char *) name, textlen-3);
 
 	end = data;
 	last = data;
@@ -529,7 +527,8 @@ static void sample_gastime(struct sample_data *info, short gastime)
 	if (gastime < 0)
 		return;
 
-	// Hmm. We have no good way to report airtime remaining
+	sample.rbt = gastime / 60;
+	if (info->callback) info->callback (DC_SAMPLE_RBT, sample, info->userdata);
 }
 
 /*
@@ -784,7 +783,7 @@ static void sample_setpoint_automatic(struct sample_data *info, unsigned char va
 	DEBUG(info->eon->base.context, "sample_setpoint_automatic(%u)", value);
 }
 
-static int handle_sample_type(const struct type_desc *desc, struct sample_data *info, enum eon_sample type, const unsigned char *data)
+static unsigned int handle_sample_type(const struct type_desc *desc, struct sample_data *info, enum eon_sample type, const unsigned char *data)
 {
 	switch (type) {
 	case ES_dtime:
@@ -892,7 +891,7 @@ static int handle_sample_type(const struct type_desc *desc, struct sample_data *
 	}
 }
 
-static int traverse_samples(unsigned short type, const struct type_desc *desc, const unsigned char *data, int len, void *user)
+static int traverse_samples(unsigned short type, const struct type_desc *desc, const unsigned char *data, unsigned int len, void *user)
 {
 	struct sample_data *info = (struct sample_data *) user;
 	suunto_eonsteel_parser_t *eon = info->eon;
@@ -902,8 +901,7 @@ static int traverse_samples(unsigned short type, const struct type_desc *desc, c
 		ERROR(eon->base.context, "Got %d bytes of data for '%s' that wants %d bytes", len, desc->desc, desc->size);
 
 	for (i = 0; i < EON_MAX_GROUP; i++) {
-		enum eon_sample type = desc->type[i];
-		int bytes = handle_sample_type(desc, info, type, data);
+		unsigned int bytes = handle_sample_type(desc, info, desc->type[i], data);
 
 		if (!bytes)
 			break;
@@ -1392,7 +1390,7 @@ static int traverse_sample_fields(suunto_eonsteel_parser_t *eon, const struct ty
 	return 0;
 }
 
-static int traverse_fields(unsigned short type, const struct type_desc *desc, const unsigned char *data, int len, void *user)
+static int traverse_fields(unsigned short type, const struct type_desc *desc, const unsigned char *data, unsigned int len, void *user)
 {
 	suunto_eonsteel_parser_t *eon = (suunto_eonsteel_parser_t *) user;
 
